componenttools.split_component_at_prolated_duration_and_do_not_fracture_crossing_spanners
=========================================================================================

.. autofunction:: abjad.tools.componenttools.split_component_at_prolated_duration_and_do_not_fracture_crossing_spanners.split_component_at_prolated_duration_and_do_not_fracture_crossing_spanners
